/* $Id: SpinBox.h,v 1.5 1999/11/06 05:50:59 glgay Exp $ */
/*
 Copyright (C) 1997, 1999 Gerald L. Gay
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(xarm_spinbox_h)
#define xarm_spinbox_h

/* ======================================================================= */
/* Include(s): */

#include <Xarm/Xarm.h>
#include <Xarm/Manager.h>

/* 
* The SpinBox only exists in versions of Motif >= 2 and CDE. 
* However, you could write one yourself and remove this restriction.  
*/

#if XmVERSION >= 2 && ! defined(XARM_HAS_CDE)

#include <Xarm/M2SpinBox.h>
#define XARM_HAS_SPINBOX

#elif defined(XARM_HAS_CDE)

#include <Xarm/CDESpinBox.h>
#define XARM_HAS_SPINBOX

#endif

#endif
